@@ -56,7 +56,8 @@ def loadFieldsDict():
     types =     {"alarm_type": "Alarm",
                  "exec_type": "Command execution",
                  "builtin_type": "Built-in function",
-                 "profile_type": "Switch profile"}
+                 "profile_type": "Switch profile",
+                 "netconnect_type": "Connect to network"}
     fields["types"] = types
     weekdays =  {"mon": "Monday",
                  "tue": "Tuesday",
@@ -70,7 +71,10 @@ def loadFieldsDict():
                  "offlineswitcher": "Enable flight mode",
                  "onlineswitcher": "Disable flight mode",
                  "bluetoothon": "Enable bluetooth",
-                 "bluetoothoff": "Disable bluetooth"}
+                 "bluetoothoff": "Disable bluetooth",
+                 "set3g": "Set Radio to 3G-only",
+                 "set2g": "Set Radio to 2G-only",
+                 "set23g": "Set Radio to 2G/3G dual mode"}
     fields["builtins"] = builtins
     return fields
     
@@ -150,7 +154,25 @@ def loadPreset(preset_name):
     return preset
 
 def getAvailableProfiles():
-        return list(dbus.Interface(dbus.SessionBus().get_object('com.nokia.profiled', '/com/nokia/profiled'), 'com.nokia.profiled').get_profiles())
+    return list(dbus.Interface(dbus.SessionBus().get_object('com.nokia.profiled', '/com/nokia/profiled'), 'com.nokia.profiled').get_profiles())
+
+def getSavedNetworks():
+    import shlex, subprocess
+    command = '''sh /opt/alarmed/get_networks.sh'''
+    args = shlex.split(command)
+    p = subprocess.Popen(args, stdout=subprocess.PIPE)
+    networks = {}
+    content = p.communicate()[0]
+    ident=""
+    switch = 0
+    for line in content.split("\n"):
+      if switch == 0:
+        ident = line.strip().replace("@32@", " ")
+        switch = 1
+      elif switch != 0:
+        networks[line[9:]] = ident
+        switch = 0
+    return networks
  
 def generateEventString(eventInfo):
     """Generates a single string from event data"""
@@ -367,22 +389,29 @@ def makeEvent(eventInfo, old_id):
         if eventInfo["content"] == b["gprsdataresetter"]:
             action.command = str("/opt/alarmed/gprsdataresetter.sh")
         elif eventInfo["content"] == b["offlineswitcher"]:
-            action.command = str(
-                               "/opt/alarmed/onlineswitcher.sh offline")
+            action.command = str("/opt/alarmed/onlineswitcher.sh offline")
         elif eventInfo["content"] == b["onlineswitcher"]:
-            action.command = str(
-                                "/opt/alarmed/onlineswitcher.sh normal")
+            action.command = str("/opt/alarmed/onlineswitcher.sh normal")
         elif eventInfo["content"] == b["bluetoothon"]:
-            action.command = str(
-                                "/opt/alarmed/bluetoothswitcher.py on")
+            action.command = str("/opt/alarmed/bluetoothswitcher.py on")
         elif eventInfo["content"] == b["bluetoothoff"]:
-            action.command = str(
-                                "/opt/alarmed/bluetoothswitcher.py off")
+            action.command = str("/opt/alarmed/bluetoothswitcher.py off")
+        elif eventInfo["content"] == b["set3g"]:
+            action.command = str("/opt/alarmed/radiomodeswitcher.sh 3g")
+        elif eventInfo["content"] == b["set2g"]:
+            action.command = str("/opt/alarmed/radiomodeswitcher.sh 2g")
+        elif eventInfo["content"] == b["set23g"]:
+            action.command = str("/opt/alarmed/radiomodeswitcher.sh 23g")
     elif eventInfo["type"] == t["profile_type"]:
         action = event.add_actions(1)[0]
         action.flags |= (alarm.ACTION_WHEN_TRIGGERED | 
                          alarm.ACTION_TYPE_EXEC)
         action.command = ("/opt/alarmed/profileswitcher.sh %s" % eventInfo["content"]).encode("utf-8")
+    elif eventInfo["type"] == t["netconnect_type"]:
+        action = event.add_actions(1)[0]
+        action.flags |= (alarm.ACTION_WHEN_TRIGGERED | 
+                         alarm.ACTION_TYPE_EXEC)
+        action.command = ("/opt/alarmed/connect_to_network.sh '%s'" % eventInfo["content"]).encode("utf-8")
     if eventInfo["schedule"] == s["every_minute"]:
         recurrence = event.add_recurrences(1)[0]
         event.recurrences_left = -1
