@@ -200,6 +200,10 @@ class AlarmedGUI(QtGui.QWidget):
         self.profilePicker = QtGui.QComboBox()
         self.row3.addWidget(self.profilePicker)
         self.profilePicker.hide()
+        #picker for saved networks (will get populated each time it loads!)
+        self.networkPicker = QtGui.QComboBox()
+        self.row3.addWidget(self.networkPicker)
+        self.networkPicker.hide()
         #picker for command line execution
         self.execPicker = QtGui.QLineEdit("Enter command")
         self.row3.addWidget(self.execPicker)
@@ -286,18 +290,21 @@ class AlarmedGUI(QtGui.QWidget):
             self.execPicker.hide()
             self.builtinPicker.hide()
             self.profilePicker.hide()
+            self.networkPicker.hide()
             self.execSavePresetButton.hide()
             self.execPresetPicker.hide()
         elif type == t["exec_type"]:
             self.builtinPicker.hide()
             self.execPicker.show()
             self.profilePicker.hide()
+            self.networkPicker.hide()
             self.execSavePresetButton.show()
             self.execPresetPicker.show()
         elif type == t["builtin_type"]:
             self.execPicker.hide()
             self.builtinPicker.show()
             self.profilePicker.hide()
+            self.networkPicker.hide()
             self.execSavePresetButton.hide()
             self.execPresetPicker.hide()
         elif type == t["profile_type"]:
@@ -305,11 +312,24 @@ class AlarmedGUI(QtGui.QWidget):
             self.builtinPicker.hide()
             self.execSavePresetButton.hide()
             self.execPresetPicker.hide()
+            self.networkPicker.hide()
             self.profilePicker.show()
             self.profilePicker.clear()
             profiles = alarmed_backend.getAvailableProfiles()
             for p in profiles:
                 self.profilePicker.addItem(p)
+        elif type == t["netconnect_type"]:
+            self.execPicker.hide()
+            self.builtinPicker.hide()
+            self.execSavePresetButton.hide()
+            self.execPresetPicker.hide()
+            self.profilePicker.hide()
+            self.networkPicker.show()
+            self.networkPicker.clear()
+            networks = alarmed_backend.getSavedNetworks()
+            for n in networks:
+                self.networkPicker.addItem(n)
+            self.networkPicker.model().sort(QtCore.Qt.AscendingOrder)
 
     def updateTypeDependent(self, type, content):
         """Updates the GUI contents of special types"""
@@ -336,6 +356,26 @@ class AlarmedGUI(QtGui.QWidget):
                     % self.eventList.currentItem().eventInfo["content"])
             self.profilePicker.setCurrentIndex(i)
             self.profilePicker.show()
+        elif type == t["netconnect_type"]:
+            self.networkPicker.clear()
+            networks = alarmed_backend.getSavedNetworks()
+            for n in networks:
+                self.networkPicker.addItem(n)
+            self.networkPicker.model().sort(QtCore.Qt.AscendingOrder)
+            network = self.eventList.currentItem().eventInfo["content"]
+            ident = ""
+            for key in networks:
+                if networks[key] == network:
+                    ident = key
+                    break
+            i = self.networkPicker.findText(ident)
+            if i == -1:
+                self.showError(
+                    '''<font color="#000000">This event has become invalid because you deleted network %s.</font>'''
+                    % ident)
+            self.networkPicker.setCurrentIndex(i)
+            self.networkPicker.show()
+            
 
     def updateScheduling(self, index):
         """Updates the GUI to fit the current schedule type"""
@@ -590,13 +630,14 @@ class AlarmedGUI(QtGui.QWidget):
             eventInfo["interval"] = self.intervalPicker.currentText()
         elif self.schedulePicker.currentText() == s["next"]:
             day = self.rWeekdayPicker.currentText()
-            if day == mon: day = 1
-            if day == tue: day = 2
-            if day == wed: day = 3
-            if day == thu: day = 4
-            if day == fri: day = 5
-            if day == sat: day = 6
-            if day == sun: day = 7
+            w = self.fields["weekdays"]
+            if day == w["mon"]: day = 1
+            if day == w["tue"]: day = 2
+            if day == w["wed"]: day = 3
+            if day == w["thu"]: day = 4
+            if day == w["fri"]: day = 5
+            if day == w["sat"]: day = 6
+            if day == w["sun"]: day = 7
             dateTime = QtCore.QDateTime.fromTime_t(int(time.time()))
             dateTime = dateTime.addDays(1)
             while dateTime.date().dayOfWeek() != day:
@@ -649,6 +690,10 @@ class AlarmedGUI(QtGui.QWidget):
         elif type == t["profile_type"]:
             content = self.profilePicker.currentText()
             eventInfo["content"] = content
+        elif type == t["netconnect_type"]:
+            content = alarmed_backend.getSavedNetworks()[self.networkPicker.currentText()]
+            content = content.replace("@32@", " ")
+            eventInfo["content"] = content
         if self.weekdays:
             eventInfo["weekdays"] = self.weekdays
         #call backend to make event
